import requests
import threading
import time

def do_get(n):
    start = time.time()
    res = requests.get('http://127.0.0.1:5000', timeout=n)
    print(time.time() - start)
    return res.content

if __name__ == '__main__':
    for i in range(1, 1000):
        try:
            print(i)
            threading.Thread(target=do_get, args=(None,)).start()
        except Exception as e:
            print(e.with_traceback(None))



import json


class Serializer:

    count = 0

    def __init__(self):
        Serializer.count += 1

    @staticmethod
    def get_func_info(data):
        info = Serializer.deserialize(data)
        return info.get("functionName"), info.get("args"), info.get("kwargs"), info.get("instanceID")

    @staticmethod
    def serialize(obj):
        return json.dumps(obj).encode()

    @staticmethod
    def deserialize(data) -> dict:
        info = json.loads(data.decode())
        return info
